Learn R Programming

freqparcoord (version 1.0.1)

posjitter: Add positive jitter.

Description

Similar to jitter, but only generating values in (0,1). A typical example of use is for an age variable, which in many data sets is truncated to the lowest integer.

Usage

posjitter(x)

Arguments

x
Vector to which jitter is to be added.

Value

The vector x + runif(length(x)).