powered by
Similar to jitter, but only generating values in (0,1). A typical example of use is for an age variable, which in many data sets is truncated to the lowest integer.
posjitter(x)
x + runif(length(x))